@@ -6,9 +6,5 @@ var classIMP_1_1algebra_1_1SpherePatch3D =
     [ "get_contains", "classIMP_1_1algebra_1_1SpherePatch3D.html#a07f278aee7f47c8bf4b5113b3842c8d6", null ],
     [ "get_plane", "classIMP_1_1algebra_1_1SpherePatch3D.html#abf412d5eb9224b9db29943be84bb5f69", null ],
     [ "get_sphere", "classIMP_1_1algebra_1_1SpherePatch3D.html#a1dabd6f5edb8aa3295bf00461069a032", null ],
-    [ "show", "classIMP_1_1algebra_1_1SpherePatch3D.html#a887c49fa757ad1e7ff1aca5a9a44bd06", null ],
-    [ "get_area", "classIMP_1_1algebra_1_1SpherePatch3D.html#a96d364ca0c2621089adcfe22945de30b", null ],
-    [ "get_bounding_box", "classIMP_1_1algebra_1_1SpherePatch3D.html#ae5375e21b4c4a14ecf4278d36cab2387", null ],
-    [ "get_sphere_patch_3d_geometry", "classIMP_1_1algebra_1_1SpherePatch3D.html#ab64eeda4f1106781fd57c3635e593b12", null ],
-    [ "set_sphere_patch_3d_geometry", "classIMP_1_1algebra_1_1SpherePatch3D.html#a45d61d6b1d79f6f08aaa5e7540b25001", null ]
+    [ "show", "classIMP_1_1algebra_1_1SpherePatch3D.html#a887c49fa757ad1e7ff1aca5a9a44bd06", null ]
 ];
\ No newline at end of file
