@@ -2,11 +2,11 @@ var classIMP_1_1atom_1_1CHARMMIdealResidueTopology =
 [
     [ "CHARMMIdealResidueTopology", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#aa08b4f488219f0fe50ac7fdd2db5d4be", null ],
     [ "CHARMMIdealResidueTopology", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#a53ca62b5ccb300cee4346944619ebbba", null ],
-    [ "do_show", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#a31090b2cea72b4a2eaf7fa0b1e9904fe", null ],
     [ "get_default_first_patch", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#a93075355644092e396257c817aedce96", null ],
     [ "get_default_last_patch", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#acdc5647566ca774ad9b0d4530ccfbbcd", null ],
+    [ "get_type_name", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#a8e6797abf0a6d3f1f3c52d97cdd373c1", null ],
+    [ "get_version_info", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#a5678ffba8f5901875f041b42fa0df56d", null ],
     [ "remove_atom", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#ac470276c79e0953c224b1d4e90a0e9b1", null ],
     [ "set_default_first_patch", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#abaeb344f4b7a50b2cd6871610588fcef", null ],
-    [ "set_default_last_patch", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#aa642538cc5ad6b874fa8b705b3cf2917", null ],
-    [ "CHARMMIdealResidueTopologiesTemp", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#ab540ffa6bbc0a0fb5e9c82d6e5a2e039", null ]
+    [ "set_default_last_patch", "classIMP_1_1atom_1_1CHARMMIdealResidueTopology.html#aa642538cc5ad6b874fa8b705b3cf2917", null ]
 ];
\ No newline at end of file
