@@ -2,6 +2,5 @@ var classIMP_1_1atom_1_1PDBSelector =
 [
     [ "PDBSelector", "classIMP_1_1atom_1_1PDBSelector.html#abb77c494c2dda105db2937473b26907d", null ],
     [ "~PDBSelector", "classIMP_1_1atom_1_1PDBSelector.html#a22442d1053fc115189a73cb3611e4d3f", null ],
-    [ "get_is_selected", "classIMP_1_1atom_1_1PDBSelector.html#a57c25407de93bb6d3d139e9593b86428", null ],
-    [ "PDBSelectorsTemp", "classIMP_1_1atom_1_1PDBSelector.html#a58618443231bab925da9a5227f9da634", null ]
+    [ "get_is_selected", "classIMP_1_1atom_1_1PDBSelector.html#a57c25407de93bb6d3d139e9593b86428", null ]
 ];
\ No newline at end of file
