@@ -1,6 +1,7 @@
 var classIMP_1_1container_1_1EventPairsOptimizerState =
 [
     [ "EventPairsOptimizerState", "classIMP_1_1container_1_1EventPairsOptimizerState.html#afdb7ee1a3d227a9c08c73d26065469d9", null ],
-    [ "do_show", "classIMP_1_1container_1_1EventPairsOptimizerState.html#a7be40a35c49adab41677523c08233e15", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1EventPairsOptimizerState.html#a6de6c10b892ee8a0dc731ba6dac0b7ba", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1EventPairsOptimizerState.html#a5efb19e8cfda9fd4c379019210082fff", null ],
     [ "update", "classIMP_1_1container_1_1EventPairsOptimizerState.html#abdb287581380f6812db7199fe4543f1a", null ]
 ];
\ No newline at end of file
