@@ -1,7 +1,9 @@
 var classIMP_1_1container_1_1ListPairContainer =
 [
-    [ "ListPairContainer", "classIMP_1_1container_1_1ListPairContainer.html#abaa030f215728582b784a8477ff3d56f", null ],
+    [ "ListPairContainer", "classIMP_1_1container_1_1ListPairContainer.html#a562c5c89bf3ce3e2563213182011391b", null ],
     [ "ListPairContainer", "classIMP_1_1container_1_1ListPairContainer.html#a5531ee0c1985081eacce64e8b1581a3e", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1ListPairContainer.html#ab50be33a9a2fcee9e306dcaf6d79160f", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1ListPairContainer.html#a7d4ac14cc0f2a87ff031fb42c94b4b1c", null ],
     [ "set_particle_pairs", "classIMP_1_1container_1_1ListPairContainer.html#af28766f314ee58e5fc417320bcd5d2be", null ],
     [ "set_particle_pairs", "classIMP_1_1container_1_1ListPairContainer.html#af69978ff1f870927730aeac0c28e10c7", null ]
 ];
\ No newline at end of file
