@@ -1,7 +1,9 @@
 var classIMP_1_1container_1_1MinimumPairRestraint =
 [
     [ "MinimumPairRestraint", "classIMP_1_1container_1_1MinimumPairRestraint.html#a9eb8eb9fdfcfe383257055de264ae393", null ],
-    [ "do_get_inputs", "classIMP_1_1container_1_1MinimumPairRestraint.html#a27c3bf78f5a6e3d9710d9357c59de3c2", null ],
+    [ "do_get_inputs", "classIMP_1_1container_1_1MinimumPairRestraint.html#a45dce2565f980871fca7ca556ed1e622", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1MinimumPairRestraint.html#a9da43b9fc87f6491aa410fa4528d2041", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1MinimumPairRestraint.html#a6c8bd9b736e8304667d82efeebd58b75", null ],
     [ "set_n", "classIMP_1_1container_1_1MinimumPairRestraint.html#ad24c376ef93b26c0da48427e3ab61b59", null ],
     [ "unprotected_evaluate", "classIMP_1_1container_1_1MinimumPairRestraint.html#aa8f092ce69207d297d7f9d7e265d41b0", null ]
 ];
\ No newline at end of file
