@@ -2,8 +2,10 @@ var classIMP_1_1container_1_1PredicateQuadsRestraint =
 [
     [ "PredicateQuadsRestraint", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#a3dada94ed0273c9b063546c9dac025d8", null ],
     [ "do_add_score_and_derivatives", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#ad99dbedd16f83586eec81446a58fe853", null ],
-    [ "do_get_inputs", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#a241da4ef87e1d826bc0138fc8b34d4e7", null ],
+    [ "do_get_inputs", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#a761ad4a71120777f6c8ab8617da3eaa0", null ],
     [ "get_indexes", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#a2ab324426e46c99d50c5fde083599230", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#a2a4b206df8f5fa49afde335660090995", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#a5e8bd9c39c43a6cf679481281b1115fe", null ],
     [ "set_is_complete", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#aeb5d5c642ec77f9e69e55f422a42183b", null ],
     [ "set_score", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#a75a50f8d26b4c3fdf81f5741bebbd582", null ],
     [ "set_unknown_score", "classIMP_1_1container_1_1PredicateQuadsRestraint.html#a6aea70e486ae4032cfe960acd43f336f", null ]
