@@ -3,5 +3,7 @@ var classIMP_1_1core_1_1ClosedCubicSpline =
     [ "ClosedCubicSpline", "classIMP_1_1core_1_1ClosedCubicSpline.html#af8606ecbbd634a0174157df73aeb3b2c", null ],
     [ "do_show", "classIMP_1_1core_1_1ClosedCubicSpline.html#a2cda584f875857c544d0d1c03cf4c685", null ],
     [ "evaluate", "classIMP_1_1core_1_1ClosedCubicSpline.html#af302c08645b121ac246a3d0534ba92f6", null ],
-    [ "evaluate_with_derivative", "classIMP_1_1core_1_1ClosedCubicSpline.html#a2058b3907144eead65dab49d1e3d8c3c", null ]
+    [ "evaluate_with_derivative", "classIMP_1_1core_1_1ClosedCubicSpline.html#a2058b3907144eead65dab49d1e3d8c3c", null ],
+    [ "get_type_name", "classIMP_1_1core_1_1ClosedCubicSpline.html#ac9c39c21d843987d15ee0fc8ca2013dc", null ],
+    [ "get_version_info", "classIMP_1_1core_1_1ClosedCubicSpline.html#afcbbd6fa56d57189e62a4fef92d0aa0a", null ]
 ];
\ No newline at end of file
