@@ -3,5 +3,7 @@ var classIMP_1_1display_1_1FilterGeometry =
     [ "FilterGeometry", "classIMP_1_1display_1_1FilterGeometry.html#a48ddb9438d24ddbc71317779b7010caa", null ],
     [ "add_geometry", "classIMP_1_1display_1_1FilterGeometry.html#ae62eb73dfa5a06f67362a8753ec3238a", null ],
     [ "add_geometry", "classIMP_1_1display_1_1FilterGeometry.html#a9fee2038ee9fb9ebe6f79b99534f237c", null ],
-    [ "do_show", "classIMP_1_1display_1_1FilterGeometry.html#a22f87ac2c0f877c37fd1ef2ed07d7a49", null ]
+    [ "get_components", "classIMP_1_1display_1_1FilterGeometry.html#a7bbe759fcc999510058497b6564ae748", null ],
+    [ "get_type_name", "classIMP_1_1display_1_1FilterGeometry.html#a3ff164e58e227e50aa7ae33bee61d843", null ],
+    [ "get_version_info", "classIMP_1_1display_1_1FilterGeometry.html#a68496093ee23aca08d1eae1cbea680e8", null ]
 ];
\ No newline at end of file
