@@ -2,7 +2,9 @@ var classIMP_1_1display_1_1SurfaceMeshGeometry =
 [
     [ "SurfaceMeshGeometry", "classIMP_1_1display_1_1SurfaceMeshGeometry.html#a93b0af289a5ce79f98213a692cd9102b", null ],
     [ "SurfaceMeshGeometry", "classIMP_1_1display_1_1SurfaceMeshGeometry.html#ae315418aec7e9d6c6bf026901ae594e5", null ],
-    [ "do_show", "classIMP_1_1display_1_1SurfaceMeshGeometry.html#ad07cd1006f172a855a69c1e49882bc40", null ],
+    [ "get_components", "classIMP_1_1display_1_1SurfaceMeshGeometry.html#a8f91ce225f18c560636d9d0557c5d357", null ],
     [ "get_faces", "classIMP_1_1display_1_1SurfaceMeshGeometry.html#a088f0266be481fb04f38d1cc63d23cd4", null ],
+    [ "get_type_name", "classIMP_1_1display_1_1SurfaceMeshGeometry.html#ac92500501ef04b3b9677b2e696f143ec", null ],
+    [ "get_version_info", "classIMP_1_1display_1_1SurfaceMeshGeometry.html#a858b92ba1e465602ace2449956ff14cc", null ],
     [ "get_vertexes", "classIMP_1_1display_1_1SurfaceMeshGeometry.html#a61efa3e3f3d86443c8c905e3244d693d", null ]
 ];
\ No newline at end of file
