@@ -4,7 +4,9 @@ var classIMP_1_1display_1_1TriangleGeometry =
     [ "TriangleGeometry", "classIMP_1_1display_1_1TriangleGeometry.html#a8880501417b489547a254c4c2003cf3d", null ],
     [ "TriangleGeometry", "classIMP_1_1display_1_1TriangleGeometry.html#a33df56da0761fbdde97e8e938c13b96a", null ],
     [ "TriangleGeometry", "classIMP_1_1display_1_1TriangleGeometry.html#a6a039b1098c7111bafe6a715fdbdc6ba", null ],
-    [ "do_show", "classIMP_1_1display_1_1TriangleGeometry.html#a2c5b572247d509b9c00cc15bfe5b38f1", null ],
+    [ "get_components", "classIMP_1_1display_1_1TriangleGeometry.html#adfa41745a62de51d6a609a2d03f55e52", null ],
     [ "get_geometry", "classIMP_1_1display_1_1TriangleGeometry.html#a3fb7310b1377825c917fe57545de7c0a", null ],
+    [ "get_type_name", "classIMP_1_1display_1_1TriangleGeometry.html#a1210ac824a8600737f52005310a665b9", null ],
+    [ "get_version_info", "classIMP_1_1display_1_1TriangleGeometry.html#a0f3e895f4366aad476b7644649e0acf1", null ],
     [ "set_geometry", "classIMP_1_1display_1_1TriangleGeometry.html#a9c7b1a40aaf76f2d29c5c38be25ce8d4", null ]
 ];
\ No newline at end of file
