@@ -6,6 +6,8 @@ var classIMP_1_1isd_1_1vonMises =
     [ "evaluate_derivative_kappa", "classIMP_1_1isd_1_1vonMises.html#ac299143d439f02401e315e5122e03089", null ],
     [ "evaluate_derivative_mu", "classIMP_1_1isd_1_1vonMises.html#ab48402c356205a3a42d2f961c973ff14", null ],
     [ "evaluate_derivative_x", "classIMP_1_1isd_1_1vonMises.html#a99f8e93dc85269449e3df503e9adeebe", null ],
+    [ "get_type_name", "classIMP_1_1isd_1_1vonMises.html#a8db4695c48bf1abd9b579f23fc3f932b", null ],
+    [ "get_version_info", "classIMP_1_1isd_1_1vonMises.html#a8cd01f336c1b44284be0c8d273c7c06c", null ],
     [ "set_kappa", "classIMP_1_1isd_1_1vonMises.html#acf8fdc00e144eec1842d847ed5b1297d", null ],
     [ "set_mu", "classIMP_1_1isd_1_1vonMises.html#a33f150df1401297c6c258b6b49ce650e", null ],
     [ "set_x", "classIMP_1_1isd_1_1vonMises.html#ae13c8b00b3021fb8a896a873256b87ce", null ]
