@@ -1,12 +1,12 @@
 var classIMP_1_1kernel_1_1Container =
 [
-    [ "Container", "classIMP_1_1kernel_1_1Container.html#a5b937a0b9ebadf1469702c1afbe07765", null ],
+    [ "Container", "classIMP_1_1kernel_1_1Container.html#a9e9028201d9335eea0f7e4728056927b", null ],
     [ "do_after_evaluate", "classIMP_1_1kernel_1_1Container.html#af2d4baa22b0dcfeeac7c699dac140f4f", null ],
     [ "do_get_outputs", "classIMP_1_1kernel_1_1Container.html#ac9da4b914e254464cfe65da1f9981f14", null ],
     [ "get_all_possible_indexes", "classIMP_1_1kernel_1_1Container.html#a0b945de854e6a5632fec678750d74271", null ],
     [ "get_all_possible_particles", "classIMP_1_1kernel_1_1Container.html#ae9c3650337d60529f8f1baf05a7cc631", null ],
+    [ "get_contents_version", "classIMP_1_1kernel_1_1Container.html#a88211f0ae6a15efc529c8f5c5f8754f4", null ],
     [ "get_is_changed", "classIMP_1_1kernel_1_1Container.html#aef59a2701832f1c6669dcd6f1231966d", null ],
     [ "get_is_decomposable", "classIMP_1_1kernel_1_1Container.html#a7e0d49634d5cc810ce18b95201292b5b", null ],
-    [ "set_is_changed", "classIMP_1_1kernel_1_1Container.html#af0044fac068502812b8b83431586607b", null ],
-    [ "ContainersTemp", "classIMP_1_1kernel_1_1Container.html#af22fbcf0df877313ccf051ecc5e5aae6", null ]
+    [ "set_is_changed", "classIMP_1_1kernel_1_1Container.html#af0044fac068502812b8b83431586607b", null ]
 ];
\ No newline at end of file
