@@ -5,5 +5,7 @@ var classIMP_1_1rotamer_1_1RotamerLibrary =
     [ "RotamerLibrary", "classIMP_1_1rotamer_1_1RotamerLibrary.html#a4a7bb75f5c200aec077b218058f34a4d", null ],
     [ "get_rotamers", "classIMP_1_1rotamer_1_1RotamerLibrary.html#a917624d3ba6e635f360c999efe4ce0f7", null ],
     [ "get_rotamers_fast", "classIMP_1_1rotamer_1_1RotamerLibrary.html#a17b121526a2716bca70671c76dc56fc5", null ],
+    [ "get_type_name", "classIMP_1_1rotamer_1_1RotamerLibrary.html#a248528514db0d8fe393bd2c212eac025", null ],
+    [ "get_version_info", "classIMP_1_1rotamer_1_1RotamerLibrary.html#a2aaef0fa97e7e1959ad60e539b1edbf6", null ],
     [ "read_library_file", "classIMP_1_1rotamer_1_1RotamerLibrary.html#aed107d8105110ef8a23079016c69d751", null ]
 ];
\ No newline at end of file
