@@ -1,14 +1,12 @@
 var distance_8h =
 [
-    [ "RMSDCalculator", "classIMP_1_1atom_1_1RMSDCalculator.html", "classIMP_1_1atom_1_1RMSDCalculator" ],
-    [ "RMSDCalculators", "distance_8h.html#a09d24cc80484a8f57a2206acd2c77017", null ],
     [ "get_component_placement_score", "distance_8h.html#acf2a8c9e18db10d978cbdb97c654eaf4", null ],
     [ "get_drms", "distance_8h.html#a10cb65062ed7027cea07ce598cbbd175", null ],
     [ "get_drmsd", "distance_8h.html#a7200d7f08e640bd3f416811320bd2f92", null ],
     [ "get_native_overlap", "distance_8h.html#ab21a3707f5810f3df642052aea0e7f73", null ],
     [ "get_pairwise_rmsd_score", "distance_8h.html#ac1ac30470fc07d7436876b1e1f7accab", null ],
     [ "get_placement_score", "distance_8h.html#ad664639ebfb7a53a52704685bbe1a803", null ],
-    [ "get_radius_of_gyration", "distance_8h.html#a81791cf8d7462fbd74685203feab5dd9", null ],
+    [ "get_radius_of_gyration", "distance_8h.html#a93f3e64bb36c2e744695df66fbd039fe", null ],
     [ "get_rigid_bodies_drms", "distance_8h.html#a58aebc295a42228173c884b97b9cb582", null ],
     [ "get_rmsd", "distance_8h.html#ad5a94b17c3cb157712a51190e5fbe0b8", null ],
     [ "get_rmsd", "distance_8h.html#a8441a01ba41cc02ac6b6ad562cd1363c", null ]
