@@ -1,12 +1,12 @@
 var domino__macros_8h =
 [
     [ "IMP_ASSIGNMENT_CONTAINER", "domino__macros_8h.html#aa2c035a9b4f292f74584348df3edd38d", null ],
-    [ "IMP_ASSIGNMENT_CONTAINER_BASE", "domino__macros_8h.html#adc96ce22dfa490603601760ba1f679a7", null ],
     [ "IMP_ASSIGNMENT_CONTAINER_INLINE", "domino__macros_8h.html#a56213933362ecbe2e250094a1a6442d8", null ],
+    [ "IMP_ASSIGNMENT_CONTAINER_METHODS", "domino__macros_8h.html#add1dbc5dedf89823db714443cd55dfda", null ],
     [ "IMP_ASSIGNMENTS_TABLE", "domino__macros_8h.html#a79c79defd5ee8761acb4c73d5c7921ca", null ],
     [ "IMP_DISCRETE_SAMPLER", "domino__macros_8h.html#a9b46e0bc211394c4e016ab9a4d9716f7", null ],
     [ "IMP_DISJOINT_SUBSET_FILTER_TABLE_DECL", "domino__macros_8h.html#a3c8c066268a662855b9f27254ad39c9b", null ],
-    [ "IMP_DISJOINT_SUBSET_FILTER_TABLE_DEF", "domino__macros_8h.html#a368a05eba65159d7ca3aca4a2fa00be7", null ],
+    [ "IMP_DISJOINT_SUBSET_FILTER_TABLE_DEF", "domino__macros_8h.html#a85c1b67d0e8044a416bd4642f95abd02", null ],
     [ "IMP_PARTICLE_STATES", "domino__macros_8h.html#a6d82e8ca92bfa7fcf4117abf7e346a36", null ],
     [ "IMP_SUBSET_FILTER", "domino__macros_8h.html#aac2fa518f1dae9fd00783858418ea449", null ],
     [ "IMP_SUBSET_FILTER_TABLE", "domino__macros_8h.html#adf80889375c80f522255d0cc7cfb8684", null ],
