@@ -1,6 +1,6 @@
 ## \example em2d/collision_cross_section.py
-## Example of how to compute the collision cross section of a molecule.
-##
+# Example of how to compute the collision cross section of a molecule.
+#
 
 
 import IMP
@@ -15,10 +15,10 @@ Example of how to compute the collision cross section of a molecule
 
 
 IMP.base.set_log_level(IMP.base.TERSE)
-m = IMP.Model()
+m = IMP.kernel.Model()
 
 fn = em2d.get_example_path("1z5s.pdb")
-prot =  atom.read_pdb(fn, m ,atom.ATOMPDBSelector())
+prot = atom.read_pdb(fn, m, atom.ATOMPDBSelector())
 atom.add_radii(prot)
 
 
@@ -28,4 +28,4 @@ pixel_size = 1.5
 img_size = 80
 ccs = em2d.CollisionCrossSection(projections, resolution, pixel_size, img_size)
 ccs.set_model_particles(IMP.atom.get_leaves(prot))
-print "CCS",ccs.get_ccs(),"A**2"
+print "CCS", ccs.get_ccs(), "A**2"
