@@ -3,5 +3,7 @@ var links_8h =
     [ "LoadLink", "classIMP_1_1rmf_1_1LoadLink.html", "classIMP_1_1rmf_1_1LoadLink" ],
     [ "SaveLink", "classIMP_1_1rmf_1_1SaveLink.html", "classIMP_1_1rmf_1_1SaveLink" ],
     [ "LoadLinks", "links_8h.html#a5aa0d87e68c02cae2df718caa6554a59", null ],
-    [ "SaveLinks", "links_8h.html#a60f972d4b711c7f859d320fc5bf0b48a", null ]
+    [ "LoadLinksTemp", "links_8h.html#a676d63b1a0f499eb69393b7ca2662095", null ],
+    [ "SaveLinks", "links_8h.html#a60f972d4b711c7f859d320fc5bf0b48a", null ],
+    [ "SaveLinksTemp", "links_8h.html#abc61891e4a8fd40aa22e9aa52ec62048", null ]
 ];
\ No newline at end of file
