@@ -1,5 +1,8 @@
 var namespaceIMP_1_1parallel =
 [
+    [ "master_communicator", "namespaceIMP_1_1parallel_1_1master__communicator.html", "namespaceIMP_1_1parallel_1_1master__communicator" ],
+    [ "subproc", "namespaceIMP_1_1parallel_1_1subproc.html", null ],
+    [ "util", "namespaceIMP_1_1parallel_1_1util.html", null ],
     [ "Context", "classIMP_1_1parallel_1_1Context.html", "classIMP_1_1parallel_1_1Context" ],
     [ "Error", "classIMP_1_1parallel_1_1Error.html", null ],
     [ "LocalSlave", "classIMP_1_1parallel_1_1LocalSlave.html", null ],
