@@ -88,103 +88,103 @@ var NAVTREE =
       [ "IMP.saxs", "md_doxygen_generated_function_example_index.html#function_example_index_saxs", null ],
       [ "IMP.statistics", "md_doxygen_generated_function_example_index.html#function_example_index_statistics", null ]
     ] ],
-    [ "Design example", "md__tmp_nightly-build-90783_imp-2_81_80_doc_design_example.html", [
-      [ "Overview", "md__tmp_nightly-build-90783_imp-2_81_80_doc_design_example.html#designexample", null ],
-      [ "Original Description", "md__tmp_nightly-build-90783_imp-2_81_80_doc_design_example.html#design_original", [
-        [ "Comments on the original description", "md__tmp_nightly-build-90783_imp-2_81_80_doc_design_example.html#design_original_comments", null ]
+    [ "Design example", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html", [
+      [ "Overview", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#designexample", null ],
+      [ "Original Description", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_original", [
+        [ "Comments on the original description", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_original_comments", null ]
       ] ],
-      [ "Design Proposal for Reading", "md__tmp_nightly-build-90783_imp-2_81_80_doc_design_example.html#design_reading", null ],
-      [ "Implementing Scoring as a IMP::Restraint", "md__tmp_nightly-build-90783_imp-2_81_80_doc_design_example.html#design_restraint", null ],
-      [ "Implementing Scoring as a IMP::PairScore", "md__tmp_nightly-build-90783_imp-2_81_80_doc_design_example.html#design_score", null ],
-      [ "Some final thoughts", "md__tmp_nightly-build-90783_imp-2_81_80_doc_design_example.html#design_final", null ]
+      [ "Design Proposal for Reading", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_reading", null ],
+      [ "Implementing Scoring as a IMP::Restraint", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_restraint", null ],
+      [ "Implementing Scoring as a IMP::PairScore", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_score", null ],
+      [ "Some final thoughts", "md__tmp_nightly-build-61576_imp-2_81_81_doc_design_example.html#design_final", null ]
     ] ],
-    [ "Developer Guide", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html", [
-      [ "Developing with IMP", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide", null ],
-      [ "Getting around IMP", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_getting_around", null ],
-      [ "Writing new code", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_new_code", [
-        [ "Coding conventions", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_conventions", [
-          [ "Indentation", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_indentation", null ],
-          [ "Names", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_names", null ],
-          [ "Passing and storing data", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_passing", null ],
-          [ "Display", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_display", null ],
-          [ "Errors", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_errors", null ],
-          [ "Namespaces", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_namespace", null ]
+    [ "Developer Guide", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html", [
+      [ "Developing with IMP", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide", null ],
+      [ "Getting around IMP", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_getting_around", null ],
+      [ "Writing new code", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_new_code", [
+        [ "Coding conventions", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_conventions", [
+          [ "Indentation", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_indentation", null ],
+          [ "Names", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_names", null ],
+          [ "Passing and storing data", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_passing", null ],
+          [ "Display", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_display", null ],
+          [ "Errors", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_errors", null ],
+          [ "Namespaces", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_namespace", null ]
         ] ],
-        [ "Documenting your code", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_documenting", null ],
-        [ "Debugging and testing your code", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_testing", null ],
-        [ "Writing Examples", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_examples", null ],
-        [ "Exporting code to Python", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_swig", null ]
+        [ "Documenting your code", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_documenting", null ],
+        [ "Debugging and testing your code", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_testing", null ],
+        [ "Writing Examples", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_examples", null ],
+        [ "Exporting code to Python", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_swig", null ]
       ] ],
-      [ "Managing your own module", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_module", null ],
-      [ "Contributing code back to the repository", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_contributing", [
-        [ "Once you have submitted code", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_supporting", null ],
-        [ "Cross platform compatibility", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_cross_platform", [
-          [ "C++ 11", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_cxx11", null ]
+      [ "Managing your own module", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_module", null ],
+      [ "Contributing code back to the repository", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_contributing", [
+        [ "Once you have submitted code", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_supporting", null ],
+        [ "Cross platform compatibility", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_cross_platform", [
+          [ "C++ 11", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_cxx11", null ]
         ] ]
       ] ],
-      [ "Good programming practices", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_cpp", null ],
-      [ "IMP gotchas", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_gotchas", null ],
-      [ "Further reading", "md__tmp_nightly-build-90783_imp-2_81_80_doc_developer_guide.html#devguide_further_reading", null ]
+      [ "Good programming practices", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_cpp", null ],
+      [ "IMP gotchas", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_gotchas", null ],
+      [ "Further reading", "md__tmp_nightly-build-61576_imp-2_81_81_doc_developer_guide.html#devguide_further_reading", null ]
     ] ],
-    [ "Installation", "md__tmp_nightly-build-90783_imp-2_81_80_doc_installation.html", [
-      [ "Building and installing basics", "md__tmp_nightly-build-90783_imp-2_81_80_doc_installation.html#installation", null ],
-      [ "Prerequisites", "md__tmp_nightly-build-90783_imp-2_81_80_doc_installation.html#installation_prereqs", [
-        [ "Getting prerequisites on a Mac", "md__tmp_nightly-build-90783_imp-2_81_80_doc_installation.html#installation_prereqs_mac", null ],
-        [ "Getting prerequisites on Windows", "md__tmp_nightly-build-90783_imp-2_81_80_doc_installation.html#installation_prereqs_windows", null ]
+    [ "Installation", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html", [
+      [ "Building and installing basics", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation", null ],
+      [ "Prerequisites", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_prereqs", [
+        [ "Getting prerequisites on a Mac", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_prereqs_mac", null ],
+        [ "Getting prerequisites on Windows", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_prereqs_windows", null ]
       ] ],
-      [ "Optional prerequisites", "md__tmp_nightly-build-90783_imp-2_81_80_doc_installation.html#installation_preqs_optional", null ],
-      [ "Where to go next", "md__tmp_nightly-build-90783_imp-2_81_80_doc_installation.html#installation_next", null ]
+      [ "Optional prerequisites", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_preqs_optional", null ],
+      [ "Where to go next", "md__tmp_nightly-build-61576_imp-2_81_81_doc_installation.html#installation_next", null ]
     ] ],
-    [ "Introduction", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html", [
-      [ "Integrative modeling", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction", [
-        [ "Example modeling efforts", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_efforts", null ],
-        [ "The four stage process", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_four_stages", null ]
+    [ "Introduction", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html", [
+      [ "Integrative modeling", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction", [
+        [ "Example modeling efforts", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_efforts", null ],
+        [ "The four stage process", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_four_stages", null ]
       ] ],
-      [ "IMP", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_imp", [
-        [ "Representation: IMP::Model", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_representation", null ],
-        [ "Decorators", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_decorators", null ],
-        [ "Representing biological molecules", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_biomolecules", null ],
-        [ "Containers", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_containers", null ],
-        [ "Constraints and Invariants", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_constraints", null ],
-        [ "Scoring", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_scoring", [
-          [ "Restraints", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_restraints", null ],
-          [ "Scoring functions", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_scoring_functions", null ]
+      [ "IMP", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_imp", [
+        [ "Representation: IMP::Model", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_representation", null ],
+        [ "Decorators", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_decorators", null ],
+        [ "Representing biological molecules", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_biomolecules", null ],
+        [ "Containers", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_containers", null ],
+        [ "Constraints and Invariants", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_constraints", null ],
+        [ "Scoring", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_scoring", [
+          [ "Restraints", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_restraints", null ],
+          [ "Scoring functions", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_scoring_functions", null ]
         ] ],
-        [ "Sampling", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_sampling", [
-          [ "Optimizers", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_optimizers", null ],
-          [ "Samplers", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_samplers", null ]
+        [ "Sampling", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_sampling", [
+          [ "Optimizers", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_optimizers", null ],
+          [ "Samplers", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_samplers", null ]
         ] ],
-        [ "Storing and analysis", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_analsysis", null ],
-        [ "Modular structure of IMP", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_modular", null ],
-        [ "Understanding what is going on", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_understanding", [
-          [ "Logging", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_logging", null ],
-          [ "Runtime checks", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_checks", null ]
+        [ "Storing and analysis", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_analsysis", null ],
+        [ "Modular structure of IMP", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_modular", null ],
+        [ "Understanding what is going on", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_understanding", [
+          [ "Logging", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_logging", null ],
+          [ "Runtime checks", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_checks", null ]
         ] ],
-        [ "Conventions", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_conventions", [
-          [ "Units", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_units", null ],
-          [ "Names", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_names", null ],
-          [ "Graphs", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_graphs", null ],
-          [ "Values and Objects (C++ only)", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_values", null ],
-          [ "Backwards compatibility and deprecation", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_backwards", null ]
+        [ "Conventions", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_conventions", [
+          [ "Units", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_units", null ],
+          [ "Names", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_names", null ],
+          [ "Graphs", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_graphs", null ],
+          [ "Values and Objects (C++ only)", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_values", null ],
+          [ "Backwards compatibility and deprecation", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_backwards", null ]
         ] ]
       ] ],
-      [ "Where to go next", "md__tmp_nightly-build-90783_imp-2_81_80_doc_introduction.html#introduction_next", null ]
+      [ "Where to go next", "md__tmp_nightly-build-61576_imp-2_81_81_doc_introduction.html#introduction_next", null ]
     ] ],
     [ "Mailing lists", "maillists.html", null ],
-    [ "ChangeLog", "md__tmp_nightly-build-90783_imp-2_81_80_ChangeLog.html", [
-      [ "For IMP 2.1", "md__tmp_nightly-build-90783_imp-2_81_80_ChangeLog.html#ChangeLog", null ],
-      [ "For IMP 2.0", "md__tmp_nightly-build-90783_imp-2_81_80_ChangeLog.html#changelog_2_0", null ]
+    [ "ChangeLog", "md__tmp_nightly-build-61576_imp-2_81_81_ChangeLog.html", [
+      [ "For IMP 2.1.1", "md__tmp_nightly-build-61576_imp-2_81_81_ChangeLog.html#ChangeLog", null ],
+      [ "For IMP 2.0", "md__tmp_nightly-build-61576_imp-2_81_81_ChangeLog.html#changelog_2_0", null ]
     ] ],
-    [ "Tools", "md__tmp_nightly-build-90783_imp-2_81_80_tools_README.html", [
-      [ "Tools", "md__tmp_nightly-build-90783_imp-2_81_80_tools_README.html#dev_tools", null ],
-      [ "Making a module", "md__tmp_nightly-build-90783_imp-2_81_80_tools_README.html#dev_tools_make_module", null ],
-      [ "Formatting your code", "md__tmp_nightly-build-90783_imp-2_81_80_tools_README.html#dev_tools_clang_format", null ],
-      [ "Checking standards", "md__tmp_nightly-build-90783_imp-2_81_80_tools_README.html#dev_tools_check_standards", null ]
+    [ "Tools", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html", [
+      [ "Tools", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html#dev_tools", null ],
+      [ "Making a module", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html#dev_tools_make_module", null ],
+      [ "Formatting your code", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html#dev_tools_clang_format", null ],
+      [ "Checking standards", "md__tmp_nightly-build-61576_imp-2_81_81_tools_README.html#dev_tools_check_standards", null ]
     ] ],
-    [ "Dependencies", "md__tmp_nightly-build-90783_imp-2_81_80_modules_kernel_doc_dependencies.html", [
-      [ "Overview", "md__tmp_nightly-build-90783_imp-2_81_80_modules_kernel_doc_dependencies.html#dependencies", null ],
-      [ "Dependency graph", "md__tmp_nightly-build-90783_imp-2_81_80_modules_kernel_doc_dependencies.html#dependency_graph", null ],
-      [ "Caching dependencies", "md__tmp_nightly-build-90783_imp-2_81_80_modules_kernel_doc_dependencies.html#dependency_caching", null ]
+    [ "Dependencies", "md__tmp_nightly-build-61576_imp-2_81_81_modules_kernel_doc_dependencies.html", [
+      [ "Overview", "md__tmp_nightly-build-61576_imp-2_81_81_modules_kernel_doc_dependencies.html#dependencies", null ],
+      [ "Dependency graph", "md__tmp_nightly-build-61576_imp-2_81_81_modules_kernel_doc_dependencies.html#dependency_graph", null ],
+      [ "Caching dependencies", "md__tmp_nightly-build-61576_imp-2_81_81_modules_kernel_doc_dependencies.html#dependency_caching", null ]
     ] ],
     [ "EMageFit protocol", "emagefit_protocol.html", [
       [ "Input data", "emagefit_protocol.html#input", null ],
