@@ -1,16 +1,20 @@
 ## \example rmf/link.py
-## This example is like module/rmf/pdb.py except that instead of creating a new hierarchy from the rmf file, it simply links the existing hierarchy to the file. This mechanism can be used for loading multiple conformations for scoring or other analysis without having to set up restraints and things each time.
+# This example is like module/rmf/pdb.py except that instead of creating a
+# new hierarchy from the rmf file, it simply links the existing hierarchy
+# to the file. This mechanism can be used for loading multiple
+# conformations for scoring or other analysis without having to set up
+# restraints and things each time.
 
 import IMP.atom
 import IMP.rmf
 import RMF
-m= IMP.Model()
+m = IMP.kernel.Model()
 
 # Create a new IMP.atom.Hierarchy from the contents of the pdb file
-h= IMP.atom.read_pdb(IMP.rmf.get_example_path("simple.pdb"), m)
+h = IMP.atom.read_pdb(IMP.rmf.get_example_path("simple.pdb"), m)
 
 # find the name for a temporary file to use to for writing the hdf5 file
-tfn=IMP.create_temporary_file_name("link", ".rmf")
+tfn = IMP.create_temporary_file_name("link", ".rmf")
 
 print "File name is", tfn
 
@@ -27,7 +31,7 @@ IMP.rmf.save_frame(rh, 0)
 del rh
 
 # reopen it, don't clear the file when opening it
-rh= RMF.open_rmf_file(tfn)
+rh = RMF.open_rmf_file(tfn)
 
 # link to the existing pdb hierarchy
 IMP.rmf.link_hierarchies(rh, [h])
