@@ -10,7 +10,14 @@ var simplify__restraint_8h =
     [ "SimpleDistances", "simplify__restraint_8h.html#a8e1b77c0230f83d3cdbbcb85c5063e30", null ],
     [ "SimpleEMFits", "simplify__restraint_8h.html#a701027c9cf638fe46a878c1f5e35c45c", null ],
     [ "SimpleExcludedVolumes", "simplify__restraint_8h.html#acdc7efec5580675b7864d0198fa0f948", null ],
+    [ "create_simple_connectivity_on_molecules", "simplify__restraint_8h.html#a888f3838b27bb49cd02d0c11a178ac24", null ],
     [ "create_simple_connectivity_on_rigid_bodies", "simplify__restraint_8h.html#a6fa8da205ac05f57ce50ac89636a5300", null ],
+    [ "create_simple_diameter", "simplify__restraint_8h.html#af13e4e629db651c29cbcf30984d8a5c8", null ],
+    [ "create_simple_distance", "simplify__restraint_8h.html#a32a8bfc08256ec16d12f8b9198a46922", null ],
+    [ "create_simple_em_fit", "simplify__restraint_8h.html#a0494ec7b58854d8f16feef9bce450fba", null ],
+    [ "create_simple_em_fit", "simplify__restraint_8h.html#a6498e69d10aa598538206b1196758551", null ],
+    [ "create_simple_excluded_volume_on_molecules", "simplify__restraint_8h.html#a9ecb06ae6f10be2b4e24d248bf08cefa", null ],
+    [ "create_simple_excluded_volume_on_rigid_bodies", "simplify__restraint_8h.html#a2030829f46f6a55ba520171c140669e2", null ],
     [ "load_em_density_map", "simplify__restraint_8h.html#a90494677f29f9fddb4bd82f2c4199f91", null ],
     [ "set_rigid_bodies", "simplify__restraint_8h.html#a0b33e071b8bc9d15a94e7f677206f34b", null ]
 ];
\ No newline at end of file
